# NotificationsHistoryDeletionTaskResponseStatus

The status of the notification history deletion task.

## Enum

* `RUNNING` (value: `'RUNNING'`)

* `FINISHED` (value: `'FINISHED'`)

* `FAILED` (value: `'FAILED'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


